==> nextcloud-21.0.8.tgz: nextcloud/apps/weather_status/l10n/sc.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Indiritzu disconnotu",
    "No result." : "Perunu resultadu.",
    "Malformed JSON data." : "Datos JSON non bàlidos.",
    "Error" : "Errore",
    "Weather status" : "Istadu de su tempus",
    "Weather status in your dashboard" : "Istadu de su tempus in su pannellu de controllu tuo",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Istadu de su tempus integradu in s'aplicatzione de su pannellu de controllu.\n    Sa positzione de s'utente si podet determinare in automàticu o definire a manu. Luegu si mustrant previsiones pro 6 oras.\n    S'istadu si podet integrare puru in àteros logos comente in s'aplicatzione de su calendàriu.",
    "Detect location" : "Rileva positzione",
    "Set custom address" : "Imposta indiritzu personalizadu",
    "Favorites" : "Preferidos",
    "More weather for {adr}" : "Àteru tempus pro {adr}",
    "Loading weather" : "Carrigamentu tempus",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "Add as favorite" : "Agiunghe comente preferidu",
    "You are not logged in." : "No as fatu s'atzessu.",
    "There was an error getting the weather status information." : "B'at àpidu un'errore in su recùperu de is informatziones de su tempus.",
    "No weather information found" : "Peruna informatzione de su tempus agatada",
    "Location not found" : "Positzione no agatada",
    "There was an error setting the location address." : "B'at àpidu un'errore impostende s'indiritzu de sa positzione.",
    "There was an error setting the location." : "B'at àpidu un'errore impostende sa positzione.",
    "There was an error saving the mode." : "B'at àpidu un'errore sarvende sa modalidade.",
    "There was an error using personal address." : "B'at àpidu un'errore impreende s'indiritzu personale.",
    "Set location for weather" : "Imposta sa positzione pro su tempus",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Istadu de su tempus integradu in s'aplicatzione de su pannellu de controllu.\n    Sa positzione de s'utente si podet determinare in automàticu o definire a manu. Luegu si mustrant previsiones pro 6 oras.\n    S'istadu si podet integrare puru in àteros logos comente in s'aplicatzione de su calendàriu.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Chelu lìmpiu a is {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nues a is {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Die bella a is {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Note bella a is {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Unu pagu de nues a is {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebidosu a is {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Abba a pagu a is {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Abba a is {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Abba meda a is {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Abba isparta a is {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Abba a pagu isparta a is {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Abba meda isparta a is {time}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.3p0.tgz: nextcloud/apps/weather_status/l10n/sc.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Indiritzu disconnotu",
    "No result." : "Perunu resultadu.",
    "Malformed JSON data." : "Datos JSON non bàlidos.",
    "Error" : "Errore",
    "Weather status" : "Istadu de su tempus",
    "Weather status in your dashboard" : "Istadu de su tempus in su pannellu de controllu tuo",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Istadu de su tempus integradu in s'aplicatzione de su pannellu de controllu.\n    Sa positzione de s'utente si podet determinare in automàticu o definire a manu. Luegu si mustrant previsiones pro 6 oras.\n    S'istadu si podet integrare puru in àteros logos comente in s'aplicatzione de su calendàriu.",
    "Detect location" : "Rileva positzione",
    "Set custom address" : "Imposta indiritzu personalizadu",
    "Favorites" : "Preferidos",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Chelu lìmpiu a is {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nues a is {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Die bella a is {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Note bella a is {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Unu pagu de nues a is {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebidosu a is {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Abba a pagu a is {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Abba a is {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Abba meda a is {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Abba isparta a is {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Abba a pagu isparta a is {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Abba meda isparta a is {time}",
    "More weather for {adr}" : "Àteru tempus pro {adr}",
    "Loading weather" : "Carrigamentu tempus",
    "Set location for weather" : "Imposta sa positzione pro su tempus",
    "Remove from favorites" : "Boga·nche dae preferidos",
    "Add as favorite" : "Agiunghe comente preferidu",
    "You are not logged in." : "No as fatu s'atzessu.",
    "There was an error getting the weather status information." : "B'at àpidu un'errore in su recùperu de is informatziones de su tempus.",
    "No weather information found" : "Peruna informatzione de su tempus agatada",
    "Location not found" : "Positzione no agatada",
    "There was an error setting the location address." : "B'at àpidu un'errore impostende s'indiritzu de sa positzione.",
    "There was an error setting the location." : "B'at àpidu un'errore impostende sa positzione.",
    "There was an error saving the mode." : "B'at àpidu un'errore sarvende sa modalidade.",
    "There was an error using personal address." : "B'at àpidu un'errore impreende s'indiritzu personale.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Istadu de su tempus integradu in s'aplicatzione de su pannellu de controllu.\n    Sa positzione de s'utente si podet determinare in automàticu o definire a manu. Luegu si mustrant previsiones pro 6 oras.\n    S'istadu si podet integrare puru in àteros logos comente in s'aplicatzione de su calendàriu."
},
"nplurals=2; plural=(n != 1);");
